package SPVM::IO;

our $VERSION = "0.211";

1;

=head1 Name

SPVM::IO - File IO, Socket, Select/Polling.

=head1 Description

IO class has methods to manipulate File IO, Socket, Select/Polling.

=head1 Modules

=over 2 

=item * L<IO::Handle|SPVM::IO::Handle>

=item * L<IO::File|SPVM::IO::File>

=item * L<IO::Socket|SPVM::IO::Socket>

=item * L<IO::Socket::INET|SPVM::IO::Socket::INET>

=item * L<IO::Socket::UNIX|SPVM::IO::Socket::UNIX>

=item * L<IO::Select|SPVM::IO::Select>

=back

=head1 Copyright & License

Copyright (c) 2023 Yuki Kimoto

MIT License

