package SPVM::IO::Socket::UNIX;



1;

=head1 Name

SPVM::IO::Socket::UNIX - Short Description

=head1 Description

The IO::Socket::UNIX class of L<SPVM> has methods for someting.

=head1 Usage

  use IO::Socket::UNIX;

=head1 Fields



=head1 Class Methods



=head1 Instance Methods




=head1 Repository



=head1 Author

[--user-name] C<[--user-email]>

=head1 Copyright & License

Copyright (c) 2023 [--user-name]

MIT License

